\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{StatProt2}[2021/02/16 LaTeX class for Statistic Exam Protocols]

% gehörig verschlankt und an die aktuelle Nutzungsweise sowie TexLive 2020 angepasst von L. Sandig
% Nicht abwärtskompatibel mit der alten "StatProt"-Klasse!

\LoadClass[a4paper, parskip=full+, 11pt,]{scrartcl}
\RequirePackage{ifthen}
\RequirePackage{amssymb}
\RequirePackage{mathtools} % automatically loads amsmath
\RequirePackage{bbm}
\RequirePackage{lmodern}
\RequirePackage[utf8]{inputenc}
\RequirePackage[ngerman]{babel}
\RequirePackage{graphicx}
\RequirePackage{microtype}
\RequirePackage{tikz}
\RequirePackage{lastpage}
\RequirePackage{enumitem}
\RequirePackage[headtopline, headsepline, footbotline, footsepline]{scrlayer-scrpage}
\RequirePackage[left=2cm, right=2cm, top=2cm, bottom=2cm,%
                includeheadfoot=true]{geometry}

% Formatierung von Aufzählungs-Labels
\setkomafont{descriptionlabel}{\rmfamily\itshape}

% Kopf-und Fußzeile konfigurieren
\addtokomafont{disposition}{\rmfamily}
\setkomafont{pageheadfoot}{\rmfamily}
\pagestyle{scrheadings}
\ihead*{Prüfer: \Prufer\\Note: \Note}
\ohead*{\Datum\\\Zeit}
\chead*{\textbf{Prüfungsprotokoll\\\Fach}}
\cfoot*{}
\ifoot*{Fachschaft Statistik}
\ofoot*{Seite \thepage/\pageref{LastPage}}

% Fragen-Zähler, wird von der `Frage`-Umgebung verwendet
\newcounter{Frage} %[Protokoll]

% Diese Befehle werden bei Benutzung überschrieben
\newcommand*{\Prufer}{}%
\newcommand*{\Note}{}%
\newcommand*{\Fachname}{}%
\newcommand*{\Fach}{}
\newcommand*{\Datum}{}%
\newcommand*{\Zeit}{}%

% Frage- und Fazit-Umgebung (auch die könnte man mal noch verschlanken)
\newenvironment*{Frage}[1]{%
 \stepcounter{Frage}%
 \begin{minipage}{\textwidth}%
  \begin{minipage}[t]{.29\textwidth}%
   \ifthenelse{\equal{\theFrage}{1}}{{\textbf{\Large Prüfer}}\\[.5ex]}{}
   {#1}
  \end{minipage}\hfill%
  \begin{minipage}[t]{.69\textwidth}
  \ifthenelse{\equal{\theFrage}{1}}{{\textbf{\Large Prüfling}}\vspace*{.5ex}\newline}{}
 }%
 {%
  \end{minipage}%
 \end{minipage}\newline\vspace*{.5ex}%
 }%

\newenvironment*{Frage*}[1]{%
 \stepcounter{Frage}%
 \begin{minipage}{\textwidth}%
  \begin{minipage}[t]{.29\textwidth}%
   {\Large Prüfer:}\vspace*{.5ex}\newline
   {#1}
  \end{minipage}\hfill%
  \begin{minipage}[t]{.69\textwidth}
   {\Large Prüfling:}\vspace*{.5ex}\newline
 }%
 {%
  \end{minipage}%
 \end{minipage}\newline\vspace*{.5ex}%
 }%

\newenvironment*{Fazit}{%
 \noindent{\Large\textbf{Fazit}}
 \begin{center}
 \begin{minipage}{0.9\textwidth}
 \itshape
}%
{\end{minipage}\end{center}}
